LocaleProvider class

Constructors

LocaleProvider()

Properties

acceptance String
acceptance
no setter
admiration String
admiration
no setter
aggressiveness String
aggressiveness
no setter
amazement String
amazement
no setter
anger String
anger
no setter
annoyance String
annoyance
no setter
anticipation String
anticipation
no setter
apprehension String
apprehension
no setter
awe String
awe
no setter
boredom String
boredom
no setter
contempt String
contempt
no setter
disapproval String
disapproval
no setter
disgust String
disgust
no setter
distraction String
distraction
no setter
ecstasy String
ecstasy
no setter
fear String
fear
no setter
grief String
grief
no setter
hashCode int
The hash code for this object.
no setterinherited
interest String
interest
no setter
joy String
joy
no setter
loathing String
loathing
no setter
love String
love
no setter
optimism String
optimism
no setter
pensiveness String
pensiveness
no setter
rage String
rage
no setter
remorse String
remorse
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sadness String
sadness
no setter
serenity String
serenity
no setter
submission String
submission
no setter
surprise String
surprise
no setter
terror String
terror
no setter
trust String
trust
no setter
vigilance String
vigilance
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

current LocaleProvider
no setter

Static Methods

load(Locale locale) Future<LocaleProvider>
maybeOf(BuildContext context) LocaleProvider?
of(BuildContext context) LocaleProvider

Constants

delegate → const AppLocalizationDelegate