LocaleProvider class
Constructors
Properties
- acceptance → String
-
acceptanceno setter - admiration → String
-
admirationno setter - aggressiveness → String
-
aggressivenessno setter - amazement → String
-
amazementno setter - anger → String
-
angerno setter - annoyance → String
-
annoyanceno setter - anticipation → String
-
anticipationno setter - apprehension → String
-
apprehensionno setter - awe → String
-
aweno setter - boredom → String
-
boredomno setter - contempt → String
-
contemptno setter - disapproval → String
-
disapprovalno setter - disgust → String
-
disgustno setter - distraction → String
-
distractionno setter - ecstasy → String
-
ecstasyno setter - fear → String
-
fearno setter - grief → String
-
griefno setter - hashCode → int
-
The hash code for this object.
no setterinherited
- interest → String
-
interestno setter - joy → String
-
joyno setter - loathing → String
-
loathingno setter - love → String
-
loveno setter - optimism → String
-
optimismno setter - pensiveness → String
-
pensivenessno setter - rage → String
-
rageno setter - remorse → String
-
remorseno setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sadness → String
-
sadnessno setter - serenity → String
-
serenityno setter - submission → String
-
submissionno setter - surprise → String
-
surpriseno setter - terror → String
-
terrorno setter - trust → String
-
trustno setter - vigilance → String
-
vigilanceno setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- current → LocaleProvider
-
no setter
Static Methods
-
load(
Locale locale) → Future< LocaleProvider> -
maybeOf(
BuildContext context) → LocaleProvider? -
of(
BuildContext context) → LocaleProvider
Constants
- delegate → const AppLocalizationDelegate